/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <libintl.h>

#include "PremiseCheck.h"
#include "sambascanner.h"

extern struct Options_Structure Options;

int Is_Accessible(const char *Filename, int Opts) {
	if (access(Filename, Opts) != 0) {
		fprintf(stderr, _("Error while trying to access '%s': %s\n"), Filename, strerror(errno));
		return 0;
	}
	return 1;
}

void ErrorMessage_NoExec(const char *Filename) {
	fprintf(stderr, "\n");
	fprintf(stderr, _("%s was either not found or is not executable. It is required for\nSambaScanner to run. Please fix this problem so SambaScanner can run.\n"), Filename);
}

int Check_Overall_Sanity() {
	if (!Is_Executable(Options.NmbLookup_Executable)) {
		ErrorMessage_NoExec("nmblookup");
		return 0;
	}
	if (!Is_Executable(Options.SmbClient_Executable)) {
		ErrorMessage_NoExec("smbclient");
		return 0;
	}
	if (!Is_Executable(Options.SmbLister_Executable)) {
		ErrorMessage_NoExec("smblister");
		fprintf(stderr, "\n");
		fprintf(stderr, _("If you have not installed SambaScanner system wide you might need to add the\nswitches '-l ./smblister' to the command line parameters so SambaScanner finds\nthe smblister tool (which is part of the SambaScanner package).\n"));
		return 0;
	}

	if (!Is_Writeable(TEMPPATH)) {
		fprintf(stderr, _("The directory for temporary files is not writeable. Please fix this before\nrunning SambaScanner again.\n"));
		return 0;
	}

	return 1;
}

