/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#include <stdio.h>
#include <pthread.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>

#include "String.h"

void Init_StringList(StringList *List) {
	List->Entries = 0;
	List->Entry = NULL;
	pthread_mutex_init(&(List->Mutex), NULL);
}

void Destroy_StringList(StringList *List) {
	int i;
	for (i = 0; i < List->Entries; i++) free(List->Entry[i]);
	free(List->Entry);
	List->Entries = 0;
	List->Entry = NULL;
}

void Remove_Trailing_Spaces(char *String) {
	int i;
	for (i = strlen(String) - 2; i >= 0; i--) {
		if (String[i] == ' ') String[i] = 0;
			else break;
	}
}

int String_Exists(StringList *List, char *String) {
	int i;
	for (i = 0; i < List->Entries; i++) {
		if (!strcasecmp(List->Entry[i], String)) return i;
	}
	return -1;
}

void Lock_Stringlist(StringList *List) {
	pthread_mutex_lock(&(List->Mutex));
}

void Unlock_Stringlist(StringList *List) {
	pthread_mutex_unlock(&(List->Mutex));
}

void Add_String(StringList *List, char *String) {
	List->Entry = (char**)realloc(List->Entry, sizeof(char**) * (List->Entries + 1));
	List->Entry[List->Entries] = (char*)malloc(sizeof(char) * (strlen(String) + 1));
	strcpy(List->Entry[List->Entries], String);
	List->Entries++;
}

void Add_String_Atomic(StringList *List, char *String) {
	Lock_Stringlist(List);
	Add_String(List, String);
	Unlock_Stringlist(List);
}

void Add_String_Unique(StringList *List, char *String) {
	if (String_Exists(List, String) != -1) return;
	Add_String(List, String);
}

void Add_String_Unique_Atomic(StringList *List, char *String) {
	Lock_Stringlist(List);
	Add_String_Unique(List, String);
	Unlock_Stringlist(List);
}

void String_Lowercase(char *String) {
	int i;
	int l = strlen(String);
	for (i = 0; i < l; i++) {
		if ((String[i] >= 'A') && (String[i] <= 'Z')) {
			String[i] -= 'A' - 'a';
		}
	}
}

char *SingularPlural(char *Singular, char *Plural, int Number) {
	return (Number == 1) ? Singular : Plural;
}

void Date_To_String(char *Buffer, int Size, time_t Time) {
	struct tm Tm;
	if (localtime_r(&Time, &Tm) == NULL) {
		fprintf(stderr, "Error converting date '%ld': %s\n", Time, strerror(errno));
		Buffer[0] = 0;
		return;
	}

	snprintf(Buffer, Size, "%04d-%02d-%02d-%02d-%02d-%02d", Tm.tm_year + 1900, Tm.tm_mon + 1, Tm.tm_mday, Tm.tm_hour, Tm.tm_min, Tm.tm_sec);
}

